// mnemonic, changes: ld becomes ld16 for 16 bit operands. ditto inc, dec, add,
// adc, sbc.
// `in` is split into 3: `in_n` for the instruction taking its address from n
// `in_c` for the one taking its address from C and `in_f` for the one that just
// sets flags. Also these instructions don't take their arguments in parentheses
// because that makes no sense.
#[macro_export]
macro_rules! euphrates_process_instructions {
    (@ $macro_name: ident, $d: ident, $e: ident, $n: ident, $nn: ident,
        $(
            [
                $(
                    $content: tt
                )*
            ]
        )*
    ) => {{
        $(
            $macro_name!($($content)*);
        )*
    }};

    ($macro_name: ident, $d: ident, $e: ident, $n: ident, $nn: ident) => {
        euphrates_process_instructions! {@ $macro_name, $d, $e, $n, $nn,
[ [0x00                ] ; nop       ; [                 ] ; no   ;  4 ; false ]
[ [0x01, n, n          ] ; ld16      ; [ BC, $nn         ] ; mem  ; 10 ; false ]
[ [0x02                ] ; ld        ; [ (BC), A         ] ; mem  ;  7 ; false ]
[ [0x03                ] ; inc16     ; [ BC              ] ; no   ;  6 ; false ]
[ [0x04                ] ; inc       ; [ B               ] ; mem  ;  4 ; false ]
[ [0x05                ] ; dec       ; [ B               ] ; mem  ;  4 ; false ]
[ [0x06, n             ] ; ld        ; [ B, $n           ] ; mem  ;  7 ; false ]
[ [0x07                ] ; rlca      ; [                 ] ; no   ;  4 ; false ]
[ [0x08                ] ; ex        ; [ AF, AF0         ] ; mem  ;  4 ; false ]
[ [0x09                ] ; add16     ; [ HL, BC          ] ; no   ; 11 ; false ]
[ [0x0A                ] ; ld        ; [ A, (BC)         ] ; mem  ;  7 ; false ]
[ [0x0B                ] ; dec16     ; [ BC              ] ; no   ;  6 ; false ]
[ [0x0C                ] ; inc       ; [ C               ] ; mem  ;  4 ; false ]
[ [0x0D                ] ; dec       ; [ C               ] ; mem  ;  4 ; false ]
[ [0x0E, n             ] ; ld        ; [ C, $n           ] ; mem  ;  7 ; false ]
[ [0x0F                ] ; rrca      ; [                 ] ; no   ;  4 ; false ]
[ [0x10, e             ] ; djnz      ; [ $e              ] ; no   ;  8 ; false ]
[ [0x11, n, n          ] ; ld16      ; [ DE, $nn         ] ; mem  ; 10 ; false ]
[ [0x12                ] ; ld        ; [ (DE), A         ] ; mem  ;  7 ; false ]
[ [0x13                ] ; inc16     ; [ DE              ] ; no   ;  6 ; false ]
[ [0x14                ] ; inc       ; [ D               ] ; mem  ;  4 ; false ]
[ [0x15                ] ; dec       ; [ D               ] ; mem  ;  4 ; false ]
[ [0x16, n             ] ; ld        ; [ D, $n           ] ; mem  ;  7 ; false ]
[ [0x17                ] ; rla       ; [                 ] ; no   ;  4 ; false ]
[ [0x18, e             ] ; jr        ; [ $e              ] ; no   ; 12 ; false ]
[ [0x19                ] ; add16     ; [ HL, DE          ] ; no   ; 11 ; false ]
[ [0x1A                ] ; ld        ; [ A, (DE)         ] ; mem  ;  7 ; false ]
[ [0x1B                ] ; dec16     ; [ DE              ] ; no   ;  6 ; false ]
[ [0x1C                ] ; inc       ; [ E               ] ; mem  ;  4 ; false ]
[ [0x1D                ] ; dec       ; [ E               ] ; mem  ;  4 ; false ]
[ [0x1E, n             ] ; ld        ; [ E, $n           ] ; mem  ;  7 ; false ]
[ [0x1F                ] ; rra       ; [                 ] ; no   ;  4 ; false ]
[ [0x20, e             ] ; jrcc      ; [ NZcc, $e        ] ; no   ;  0 ; false ]
[ [0x21, n, n          ] ; ld16      ; [ HL, $nn         ] ; mem  ; 10 ; false ]
[ [0x22, n, n          ] ; ld16      ; [ ($nn), HL       ] ; mem  ; 16 ; false ]
[ [0x23                ] ; inc16     ; [ HL              ] ; no   ;  6 ; false ]
[ [0x24                ] ; inc       ; [ H               ] ; mem  ;  4 ; false ]
[ [0x25                ] ; dec       ; [ H               ] ; mem  ;  4 ; false ]
[ [0x26, n             ] ; ld        ; [ H, $n           ] ; mem  ;  7 ; false ]
[ [0x27                ] ; daa       ; [                 ] ; no   ;  4 ; false ]
[ [0x28, e             ] ; jrcc      ; [ Zcc, $e         ] ; no   ;  0 ; false ]
[ [0x29                ] ; add16     ; [ HL, HL          ] ; no   ; 11 ; false ]
[ [0x2A, n, n          ] ; ld16      ; [ HL, ($nn)       ] ; mem  ; 16 ; false ]
[ [0x2B                ] ; dec16     ; [ HL              ] ; no   ;  6 ; false ]
[ [0x2C                ] ; inc       ; [ L               ] ; mem  ;  4 ; false ]
[ [0x2D                ] ; dec       ; [ L               ] ; mem  ;  4 ; false ]
[ [0x2E, n             ] ; ld        ; [ L, $n           ] ; mem  ;  7 ; false ]
[ [0x2F                ] ; cpl       ; [                 ] ; no   ;  4 ; false ]
[ [0x30, e             ] ; jrcc      ; [ NCcc, $e        ] ; no   ;  0 ; false ]
[ [0x31, n, n          ] ; ld16      ; [ SP, $nn         ] ; mem  ; 10 ; false ]
[ [0x32, n, n          ] ; ld        ; [ ($nn), A        ] ; mem  ; 13 ; false ]
[ [0x33                ] ; inc16     ; [ SP              ] ; no   ;  6 ; false ]
[ [0x34                ] ; inc       ; [ (HL)            ] ; mem  ; 11 ; false ]
[ [0x35                ] ; dec       ; [ (HL)            ] ; mem  ; 11 ; false ]
[ [0x36, n             ] ; ld        ; [ (HL), $n        ] ; mem  ; 10 ; false ]
[ [0x37                ] ; scf       ; [                 ] ; no   ;  4 ; false ]
[ [0x38, e             ] ; jrcc      ; [ Ccc, $e         ] ; no   ;  0 ; false ]
[ [0x39                ] ; add16     ; [ HL, SP          ] ; no   ; 11 ; false ]
[ [0x3A, n, n          ] ; ld        ; [ A, ($nn)        ] ; mem  ; 13 ; false ]
[ [0x3B                ] ; dec16     ; [ SP              ] ; no   ;  6 ; false ]
[ [0x3C                ] ; inc       ; [ A               ] ; mem  ;  4 ; false ]
[ [0x3D                ] ; dec       ; [ A               ] ; mem  ;  4 ; false ]
[ [0x3E, n             ] ; ld        ; [ A, $n           ] ; mem  ;  7 ; false ]
[ [0x3F                ] ; ccf       ; [                 ] ; no   ;  4 ; false ]
[ [0x40                ] ; ld        ; [ B, B            ] ; mem  ;  4 ; false ]
[ [0x41                ] ; ld        ; [ B, C            ] ; mem  ;  4 ; false ]
[ [0x42                ] ; ld        ; [ B, D            ] ; mem  ;  4 ; false ]
[ [0x43                ] ; ld        ; [ B, E            ] ; mem  ;  4 ; false ]
[ [0x44                ] ; ld        ; [ B, H            ] ; mem  ;  4 ; false ]
[ [0x45                ] ; ld        ; [ B, L            ] ; mem  ;  4 ; false ]
[ [0x46                ] ; ld        ; [ B, (HL)         ] ; mem  ;  7 ; false ]
[ [0x47                ] ; ld        ; [ B, A            ] ; mem  ;  4 ; false ]
[ [0x48                ] ; ld        ; [ C, B            ] ; mem  ;  4 ; false ]
[ [0x49                ] ; ld        ; [ C, C            ] ; mem  ;  4 ; false ]
[ [0x4A                ] ; ld        ; [ C, D            ] ; mem  ;  4 ; false ]
[ [0x4B                ] ; ld        ; [ C, E            ] ; mem  ;  4 ; false ]
[ [0x4C                ] ; ld        ; [ C, H            ] ; mem  ;  4 ; false ]
[ [0x4D                ] ; ld        ; [ C, L            ] ; mem  ;  4 ; false ]
[ [0x4E                ] ; ld        ; [ C, (HL)         ] ; mem  ;  7 ; false ]
[ [0x4F                ] ; ld        ; [ C, A            ] ; mem  ;  4 ; false ]
[ [0x50                ] ; ld        ; [ D, B            ] ; mem  ;  4 ; false ]
[ [0x51                ] ; ld        ; [ D, C            ] ; mem  ;  4 ; false ]
[ [0x52                ] ; ld        ; [ D, D            ] ; mem  ;  4 ; false ]
[ [0x53                ] ; ld        ; [ D, E            ] ; mem  ;  4 ; false ]
[ [0x54                ] ; ld        ; [ D, H            ] ; mem  ;  4 ; false ]
[ [0x55                ] ; ld        ; [ D, L            ] ; mem  ;  4 ; false ]
[ [0x56                ] ; ld        ; [ D, (HL)         ] ; mem  ;  7 ; false ]
[ [0x57                ] ; ld        ; [ D, A            ] ; mem  ;  4 ; false ]
[ [0x58                ] ; ld        ; [ E, B            ] ; mem  ;  4 ; false ]
[ [0x59                ] ; ld        ; [ E, C            ] ; mem  ;  4 ; false ]
[ [0x5A                ] ; ld        ; [ E, D            ] ; mem  ;  4 ; false ]
[ [0x5B                ] ; ld        ; [ E, E            ] ; mem  ;  4 ; false ]
[ [0x5C                ] ; ld        ; [ E, H            ] ; mem  ;  4 ; false ]
[ [0x5D                ] ; ld        ; [ E, L            ] ; mem  ;  4 ; false ]
[ [0x5E                ] ; ld        ; [ E, (HL)         ] ; mem  ;  7 ; false ]
[ [0x5F                ] ; ld        ; [ E, A            ] ; mem  ;  4 ; false ]
[ [0x60                ] ; ld        ; [ H, B            ] ; mem  ;  4 ; false ]
[ [0x61                ] ; ld        ; [ H, C            ] ; mem  ;  4 ; false ]
[ [0x62                ] ; ld        ; [ H, D            ] ; mem  ;  4 ; false ]
[ [0x63                ] ; ld        ; [ H, E            ] ; mem  ;  4 ; false ]
[ [0x64                ] ; ld        ; [ H, H            ] ; mem  ;  4 ; false ]
[ [0x65                ] ; ld        ; [ H, L            ] ; mem  ;  4 ; false ]
[ [0x66                ] ; ld        ; [ H, (HL)         ] ; mem  ;  7 ; false ]
[ [0x67                ] ; ld        ; [ H, A            ] ; mem  ;  4 ; false ]
[ [0x68                ] ; ld        ; [ L, B            ] ; mem  ;  4 ; false ]
[ [0x69                ] ; ld        ; [ L, C            ] ; mem  ;  4 ; false ]
[ [0x6A                ] ; ld        ; [ L, D            ] ; mem  ;  4 ; false ]
[ [0x6B                ] ; ld        ; [ L, E            ] ; mem  ;  4 ; false ]
[ [0x6C                ] ; ld        ; [ L, H            ] ; mem  ;  4 ; false ]
[ [0x6D                ] ; ld        ; [ L, L            ] ; mem  ;  4 ; false ]
[ [0x6E                ] ; ld        ; [ L, (HL)         ] ; mem  ;  7 ; false ]
[ [0x6F                ] ; ld        ; [ L, A            ] ; mem  ;  4 ; false ]
[ [0x70                ] ; ld        ; [ (HL), B         ] ; mem  ;  7 ; false ]
[ [0x71                ] ; ld        ; [ (HL), C         ] ; mem  ;  7 ; false ]
[ [0x72                ] ; ld        ; [ (HL), D         ] ; mem  ;  7 ; false ]
[ [0x73                ] ; ld        ; [ (HL), E         ] ; mem  ;  7 ; false ]
[ [0x74                ] ; ld        ; [ (HL), H         ] ; mem  ;  7 ; false ]
[ [0x75                ] ; ld        ; [ (HL), L         ] ; mem  ;  7 ; false ]
[ [0x76                ] ; halt      ; [                 ] ; no   ;  4 ; false ]
[ [0x77                ] ; ld        ; [ (HL), A         ] ; mem  ;  7 ; false ]
[ [0x78                ] ; ld        ; [ A, B            ] ; mem  ;  4 ; false ]
[ [0x79                ] ; ld        ; [ A, C            ] ; mem  ;  4 ; false ]
[ [0x7A                ] ; ld        ; [ A, D            ] ; mem  ;  4 ; false ]
[ [0x7B                ] ; ld        ; [ A, E            ] ; mem  ;  4 ; false ]
[ [0x7C                ] ; ld        ; [ A, H            ] ; mem  ;  4 ; false ]
[ [0x7D                ] ; ld        ; [ A, L            ] ; mem  ;  4 ; false ]
[ [0x7E                ] ; ld        ; [ A, (HL)         ] ; mem  ;  7 ; false ]
[ [0x7F                ] ; ld        ; [ A, A            ] ; mem  ;  4 ; false ]
[ [0x80                ] ; add       ; [ A, B            ] ; mem  ;  4 ; false ]
[ [0x81                ] ; add       ; [ A, C            ] ; mem  ;  4 ; false ]
[ [0x82                ] ; add       ; [ A, D            ] ; mem  ;  4 ; false ]
[ [0x83                ] ; add       ; [ A, E            ] ; mem  ;  4 ; false ]
[ [0x84                ] ; add       ; [ A, H            ] ; mem  ;  4 ; false ]
[ [0x85                ] ; add       ; [ A, L            ] ; mem  ;  4 ; false ]
[ [0x86                ] ; add       ; [ A, (HL)         ] ; mem  ;  7 ; false ]
[ [0x87                ] ; add       ; [ A, A            ] ; mem  ;  4 ; false ]
[ [0x88                ] ; adc       ; [ A, B            ] ; mem  ;  4 ; false ]
[ [0x89                ] ; adc       ; [ A, C            ] ; mem  ;  4 ; false ]
[ [0x8A                ] ; adc       ; [ A, D            ] ; mem  ;  4 ; false ]
[ [0x8B                ] ; adc       ; [ A, E            ] ; mem  ;  4 ; false ]
[ [0x8C                ] ; adc       ; [ A, H            ] ; mem  ;  4 ; false ]
[ [0x8D                ] ; adc       ; [ A, L            ] ; mem  ;  4 ; false ]
[ [0x8E                ] ; adc       ; [ A, (HL)         ] ; mem  ;  7 ; false ]
[ [0x8F                ] ; adc       ; [ A, A            ] ; mem  ;  4 ; false ]
[ [0x90                ] ; sub       ; [ A, B            ] ; mem  ;  4 ; false ]
[ [0x91                ] ; sub       ; [ A, C            ] ; mem  ;  4 ; false ]
[ [0x92                ] ; sub       ; [ A, D            ] ; mem  ;  4 ; false ]
[ [0x93                ] ; sub       ; [ A, E            ] ; mem  ;  4 ; false ]
[ [0x94                ] ; sub       ; [ A, H            ] ; mem  ;  4 ; false ]
[ [0x95                ] ; sub       ; [ A, L            ] ; mem  ;  4 ; false ]
[ [0x96                ] ; sub       ; [ A, (HL)         ] ; mem  ;  7 ; false ]
[ [0x97                ] ; sub       ; [ A, A            ] ; mem  ;  4 ; false ]
[ [0x98                ] ; sbc       ; [ A, B            ] ; mem  ;  4 ; false ]
[ [0x99                ] ; sbc       ; [ A, C            ] ; mem  ;  4 ; false ]
[ [0x9A                ] ; sbc       ; [ A, D            ] ; mem  ;  4 ; false ]
[ [0x9B                ] ; sbc       ; [ A, E            ] ; mem  ;  4 ; false ]
[ [0x9C                ] ; sbc       ; [ A, H            ] ; mem  ;  4 ; false ]
[ [0x9D                ] ; sbc       ; [ A, L            ] ; mem  ;  4 ; false ]
[ [0x9E                ] ; sbc       ; [ A, (HL)         ] ; mem  ;  7 ; false ]
[ [0x9F                ] ; sbc       ; [ A, A            ] ; mem  ;  4 ; false ]
[ [0xA0                ] ; and       ; [ B               ] ; mem  ;  4 ; false ]
[ [0xA1                ] ; and       ; [ C               ] ; mem  ;  4 ; false ]
[ [0xA2                ] ; and       ; [ D               ] ; mem  ;  4 ; false ]
[ [0xA3                ] ; and       ; [ E               ] ; mem  ;  4 ; false ]
[ [0xA4                ] ; and       ; [ H               ] ; mem  ;  4 ; false ]
[ [0xA5                ] ; and       ; [ L               ] ; mem  ;  4 ; false ]
[ [0xA6                ] ; and       ; [ (HL)            ] ; mem  ;  7 ; false ]
[ [0xA7                ] ; and       ; [ A               ] ; mem  ;  4 ; false ]
[ [0xA8                ] ; xor       ; [ B               ] ; mem  ;  4 ; false ]
[ [0xA9                ] ; xor       ; [ C               ] ; mem  ;  4 ; false ]
[ [0xAA                ] ; xor       ; [ D               ] ; mem  ;  4 ; false ]
[ [0xAB                ] ; xor       ; [ E               ] ; mem  ;  4 ; false ]
[ [0xAC                ] ; xor       ; [ H               ] ; mem  ;  4 ; false ]
[ [0xAD                ] ; xor       ; [ L               ] ; mem  ;  4 ; false ]
[ [0xAE                ] ; xor       ; [ (HL)            ] ; mem  ;  7 ; false ]
[ [0xAF                ] ; xor       ; [ A               ] ; mem  ;  4 ; false ]
[ [0xB0                ] ; or        ; [ B               ] ; mem  ;  4 ; false ]
[ [0xB1                ] ; or        ; [ C               ] ; mem  ;  4 ; false ]
[ [0xB2                ] ; or        ; [ D               ] ; mem  ;  4 ; false ]
[ [0xB3                ] ; or        ; [ E               ] ; mem  ;  4 ; false ]
[ [0xB4                ] ; or        ; [ H               ] ; mem  ;  4 ; false ]
[ [0xB5                ] ; or        ; [ L               ] ; mem  ;  4 ; false ]
[ [0xB6                ] ; or        ; [ (HL)            ] ; mem  ;  7 ; false ]
[ [0xB7                ] ; or        ; [ A               ] ; mem  ;  4 ; false ]
[ [0xB8                ] ; cp        ; [ B               ] ; mem  ;  4 ; false ]
[ [0xB9                ] ; cp        ; [ C               ] ; mem  ;  4 ; false ]
[ [0xBA                ] ; cp        ; [ D               ] ; mem  ;  4 ; false ]
[ [0xBB                ] ; cp        ; [ E               ] ; mem  ;  4 ; false ]
[ [0xBC                ] ; cp        ; [ H               ] ; mem  ;  4 ; false ]
[ [0xBD                ] ; cp        ; [ L               ] ; mem  ;  4 ; false ]
[ [0xBE                ] ; cp        ; [ (HL)            ] ; mem  ;  7 ; false ]
[ [0xBF                ] ; cp        ; [ A               ] ; mem  ;  4 ; false ]
[ [0xC0                ] ; retcc     ; [ NZcc            ] ; mem  ;  5 ; false ]
[ [0xC1                ] ; pop       ; [ BC              ] ; mem  ; 10 ; false ]
[ [0xC2, n, n          ] ; jpcc      ; [ NZcc, $nn       ] ; no   ; 10 ; false ]
[ [0xC3, n, n          ] ; jp        ; [ $nn             ] ; no   ; 10 ; false ]
[ [0xC4, n, n          ] ; callcc    ; [ NZcc, $nn       ] ; mem  ;  0 ; false ]
[ [0xC5                ] ; push      ; [ BC              ] ; mem  ; 11 ; false ]
[ [0xC6, n             ] ; add       ; [ A, $n           ] ; mem  ;  7 ; false ]
[ [0xC7                ] ; rst       ; [ 0x00            ] ; mem  ; 11 ; false ]
[ [0xC8                ] ; retcc     ; [ Zcc             ] ; mem  ;  5 ; false ]
[ [0xC9                ] ; ret       ; [                 ] ; mem  ; 10 ; false ]
[ [0xCA, n, n          ] ; jpcc      ; [ Zcc, $nn        ] ; no   ; 10 ; false ]
[ [0xCB, 0x00          ] ; rlc       ; [ B               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x01          ] ; rlc       ; [ C               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x02          ] ; rlc       ; [ D               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x03          ] ; rlc       ; [ E               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x04          ] ; rlc       ; [ H               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x05          ] ; rlc       ; [ L               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x06          ] ; rlc       ; [ (HL)            ] ; mem  ; 15 ; false ]
[ [0xCB, 0x07          ] ; rlc       ; [ A               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x08          ] ; rrc       ; [ B               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x09          ] ; rrc       ; [ C               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x0A          ] ; rrc       ; [ D               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x0B          ] ; rrc       ; [ E               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x0C          ] ; rrc       ; [ H               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x0D          ] ; rrc       ; [ L               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x0E          ] ; rrc       ; [ (HL)            ] ; mem  ; 15 ; false ]
[ [0xCB, 0x0F          ] ; rrc       ; [ A               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x10          ] ; rl        ; [ B               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x11          ] ; rl        ; [ C               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x12          ] ; rl        ; [ D               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x13          ] ; rl        ; [ E               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x14          ] ; rl        ; [ H               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x15          ] ; rl        ; [ L               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x16          ] ; rl        ; [ (HL)            ] ; mem  ; 15 ; false ]
[ [0xCB, 0x17          ] ; rl        ; [ A               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x18          ] ; rr        ; [ B               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x19          ] ; rr        ; [ C               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x1A          ] ; rr        ; [ D               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x1B          ] ; rr        ; [ E               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x1C          ] ; rr        ; [ H               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x1D          ] ; rr        ; [ L               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x1E          ] ; rr        ; [ (HL)            ] ; mem  ; 15 ; false ]
[ [0xCB, 0x1F          ] ; rr        ; [ A               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x20          ] ; sla       ; [ B               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x21          ] ; sla       ; [ C               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x22          ] ; sla       ; [ D               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x23          ] ; sla       ; [ E               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x24          ] ; sla       ; [ H               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x25          ] ; sla       ; [ L               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x26          ] ; sla       ; [ (HL)            ] ; mem  ; 15 ; false ]
[ [0xCB, 0x27          ] ; sla       ; [ A               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x28          ] ; sra       ; [ B               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x29          ] ; sra       ; [ C               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x2A          ] ; sra       ; [ D               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x2B          ] ; sra       ; [ E               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x2C          ] ; sra       ; [ H               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x2D          ] ; sra       ; [ L               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x2E          ] ; sra       ; [ (HL)            ] ; mem  ; 15 ; false ]
[ [0xCB, 0x2F          ] ; sra       ; [ A               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x30          ] ; sll       ; [ B               ] ; mem  ;  8 ; true  ]
[ [0xCB, 0x31          ] ; sll       ; [ C               ] ; mem  ;  8 ; true  ]
[ [0xCB, 0x32          ] ; sll       ; [ D               ] ; mem  ;  8 ; true  ]
[ [0xCB, 0x33          ] ; sll       ; [ E               ] ; mem  ;  8 ; true  ]
[ [0xCB, 0x34          ] ; sll       ; [ H               ] ; mem  ;  8 ; true  ]
[ [0xCB, 0x35          ] ; sll       ; [ L               ] ; mem  ;  8 ; true  ]
[ [0xCB, 0x36          ] ; sll       ; [ (HL)            ] ; mem  ; 15 ; true  ]
[ [0xCB, 0x37          ] ; sll       ; [ A               ] ; mem  ;  8 ; true  ]
[ [0xCB, 0x38          ] ; srl       ; [ B               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x39          ] ; srl       ; [ C               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x3A          ] ; srl       ; [ D               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x3B          ] ; srl       ; [ E               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x3C          ] ; srl       ; [ H               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x3D          ] ; srl       ; [ L               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x3E          ] ; srl       ; [ (HL)            ] ; mem  ; 15 ; false ]
[ [0xCB, 0x3F          ] ; srl       ; [ A               ] ; mem  ;  8 ; false ]
[ [0xCB, 0x40          ] ; bit       ; [ 0, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x41          ] ; bit       ; [ 0, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x42          ] ; bit       ; [ 0, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x43          ] ; bit       ; [ 0, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x44          ] ; bit       ; [ 0, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x45          ] ; bit       ; [ 0, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x46          ] ; bit       ; [ 0, (HL)         ] ; mem  ; 12 ; false ]
[ [0xCB, 0x47          ] ; bit       ; [ 0, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x48          ] ; bit       ; [ 1, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x49          ] ; bit       ; [ 1, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x4A          ] ; bit       ; [ 1, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x4B          ] ; bit       ; [ 1, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x4C          ] ; bit       ; [ 1, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x4D          ] ; bit       ; [ 1, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x4E          ] ; bit       ; [ 1, (HL)         ] ; mem  ; 12 ; false ]
[ [0xCB, 0x4F          ] ; bit       ; [ 1, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x50          ] ; bit       ; [ 2, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x51          ] ; bit       ; [ 2, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x52          ] ; bit       ; [ 2, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x53          ] ; bit       ; [ 2, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x54          ] ; bit       ; [ 2, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x55          ] ; bit       ; [ 2, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x56          ] ; bit       ; [ 2, (HL)         ] ; mem  ; 12 ; false ]
[ [0xCB, 0x57          ] ; bit       ; [ 2, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x58          ] ; bit       ; [ 3, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x59          ] ; bit       ; [ 3, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x5A          ] ; bit       ; [ 3, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x5B          ] ; bit       ; [ 3, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x5C          ] ; bit       ; [ 3, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x5D          ] ; bit       ; [ 3, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x5E          ] ; bit       ; [ 3, (HL)         ] ; mem  ; 12 ; false ]
[ [0xCB, 0x5F          ] ; bit       ; [ 3, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x60          ] ; bit       ; [ 4, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x61          ] ; bit       ; [ 4, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x62          ] ; bit       ; [ 4, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x63          ] ; bit       ; [ 4, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x64          ] ; bit       ; [ 4, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x65          ] ; bit       ; [ 4, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x66          ] ; bit       ; [ 4, (HL)         ] ; mem  ; 12 ; false ]
[ [0xCB, 0x67          ] ; bit       ; [ 4, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x68          ] ; bit       ; [ 5, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x69          ] ; bit       ; [ 5, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x6A          ] ; bit       ; [ 5, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x6B          ] ; bit       ; [ 5, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x6C          ] ; bit       ; [ 5, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x6D          ] ; bit       ; [ 5, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x6E          ] ; bit       ; [ 5, (HL)         ] ; mem  ; 12 ; false ]
[ [0xCB, 0x6F          ] ; bit       ; [ 5, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x70          ] ; bit       ; [ 6, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x71          ] ; bit       ; [ 6, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x72          ] ; bit       ; [ 6, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x73          ] ; bit       ; [ 6, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x74          ] ; bit       ; [ 6, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x75          ] ; bit       ; [ 6, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x76          ] ; bit       ; [ 6, (HL)         ] ; mem  ; 12 ; false ]
[ [0xCB, 0x77          ] ; bit       ; [ 6, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x78          ] ; bit       ; [ 7, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x79          ] ; bit       ; [ 7, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x7A          ] ; bit       ; [ 7, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x7B          ] ; bit       ; [ 7, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x7C          ] ; bit       ; [ 7, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x7D          ] ; bit       ; [ 7, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x7E          ] ; bit       ; [ 7, (HL)         ] ; mem  ; 12 ; false ]
[ [0xCB, 0x7F          ] ; bit       ; [ 7, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x80          ] ; res       ; [ 0, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x81          ] ; res       ; [ 0, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x82          ] ; res       ; [ 0, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x83          ] ; res       ; [ 0, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x84          ] ; res       ; [ 0, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x85          ] ; res       ; [ 0, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x86          ] ; res       ; [ 0, (HL)         ] ; mem  ; 15 ; false ]
[ [0xCB, 0x87          ] ; res       ; [ 0, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x88          ] ; res       ; [ 1, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x89          ] ; res       ; [ 1, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x8A          ] ; res       ; [ 1, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x8B          ] ; res       ; [ 1, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x8C          ] ; res       ; [ 1, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x8D          ] ; res       ; [ 1, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x8E          ] ; res       ; [ 1, (HL)         ] ; mem  ; 15 ; false ]
[ [0xCB, 0x8F          ] ; res       ; [ 1, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x90          ] ; res       ; [ 2, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x91          ] ; res       ; [ 2, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x92          ] ; res       ; [ 2, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x93          ] ; res       ; [ 2, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x94          ] ; res       ; [ 2, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x95          ] ; res       ; [ 2, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x96          ] ; res       ; [ 2, (HL)         ] ; mem  ; 15 ; false ]
[ [0xCB, 0x97          ] ; res       ; [ 2, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x98          ] ; res       ; [ 3, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x99          ] ; res       ; [ 3, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x9A          ] ; res       ; [ 3, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x9B          ] ; res       ; [ 3, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x9C          ] ; res       ; [ 3, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x9D          ] ; res       ; [ 3, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0x9E          ] ; res       ; [ 3, (HL)         ] ; mem  ; 15 ; false ]
[ [0xCB, 0x9F          ] ; res       ; [ 3, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xA0          ] ; res       ; [ 4, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xA1          ] ; res       ; [ 4, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xA2          ] ; res       ; [ 4, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xA3          ] ; res       ; [ 4, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xA4          ] ; res       ; [ 4, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xA5          ] ; res       ; [ 4, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xA6          ] ; res       ; [ 4, (HL)         ] ; mem  ; 15 ; false ]
[ [0xCB, 0xA7          ] ; res       ; [ 4, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xA8          ] ; res       ; [ 5, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xA9          ] ; res       ; [ 5, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xAA          ] ; res       ; [ 5, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xAB          ] ; res       ; [ 5, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xAC          ] ; res       ; [ 5, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xAD          ] ; res       ; [ 5, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xAE          ] ; res       ; [ 5, (HL)         ] ; mem  ; 15 ; false ]
[ [0xCB, 0xAF          ] ; res       ; [ 5, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xB0          ] ; res       ; [ 6, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xB1          ] ; res       ; [ 6, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xB2          ] ; res       ; [ 6, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xB3          ] ; res       ; [ 6, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xB4          ] ; res       ; [ 6, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xB5          ] ; res       ; [ 6, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xB6          ] ; res       ; [ 6, (HL)         ] ; mem  ; 15 ; false ]
[ [0xCB, 0xB7          ] ; res       ; [ 6, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xB8          ] ; res       ; [ 7, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xB9          ] ; res       ; [ 7, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xBA          ] ; res       ; [ 7, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xBB          ] ; res       ; [ 7, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xBC          ] ; res       ; [ 7, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xBD          ] ; res       ; [ 7, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xBE          ] ; res       ; [ 7, (HL)         ] ; mem  ; 15 ; false ]
[ [0xCB, 0xBF          ] ; res       ; [ 7, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xC0          ] ; set       ; [ 0, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xC1          ] ; set       ; [ 0, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xC2          ] ; set       ; [ 0, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xC3          ] ; set       ; [ 0, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xC4          ] ; set       ; [ 0, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xC5          ] ; set       ; [ 0, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xC6          ] ; set       ; [ 0, (HL)         ] ; mem  ; 15 ; false ]
[ [0xCB, 0xC7          ] ; set       ; [ 0, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xC8          ] ; set       ; [ 1, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xC9          ] ; set       ; [ 1, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xCA          ] ; set       ; [ 1, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xCB          ] ; set       ; [ 1, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xCC          ] ; set       ; [ 1, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xCD          ] ; set       ; [ 1, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xCE          ] ; set       ; [ 1, (HL)         ] ; mem  ; 15 ; false ]
[ [0xCB, 0xCF          ] ; set       ; [ 1, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xD0          ] ; set       ; [ 2, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xD1          ] ; set       ; [ 2, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xD2          ] ; set       ; [ 2, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xD3          ] ; set       ; [ 2, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xD4          ] ; set       ; [ 2, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xD5          ] ; set       ; [ 2, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xD6          ] ; set       ; [ 2, (HL)         ] ; mem  ; 15 ; false ]
[ [0xCB, 0xD7          ] ; set       ; [ 2, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xD8          ] ; set       ; [ 3, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xD9          ] ; set       ; [ 3, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xDA          ] ; set       ; [ 3, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xDB          ] ; set       ; [ 3, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xDC          ] ; set       ; [ 3, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xDD          ] ; set       ; [ 3, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xDE          ] ; set       ; [ 3, (HL)         ] ; mem  ; 15 ; false ]
[ [0xCB, 0xDF          ] ; set       ; [ 3, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xE0          ] ; set       ; [ 4, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xE1          ] ; set       ; [ 4, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xE2          ] ; set       ; [ 4, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xE3          ] ; set       ; [ 4, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xE4          ] ; set       ; [ 4, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xE5          ] ; set       ; [ 4, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xE6          ] ; set       ; [ 4, (HL)         ] ; mem  ; 15 ; false ]
[ [0xCB, 0xE7          ] ; set       ; [ 4, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xE8          ] ; set       ; [ 5, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xE9          ] ; set       ; [ 5, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xEA          ] ; set       ; [ 5, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xEB          ] ; set       ; [ 5, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xEC          ] ; set       ; [ 5, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xED          ] ; set       ; [ 5, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xEE          ] ; set       ; [ 5, (HL)         ] ; mem  ; 15 ; false ]
[ [0xCB, 0xEF          ] ; set       ; [ 5, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xF0          ] ; set       ; [ 6, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xF1          ] ; set       ; [ 6, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xF2          ] ; set       ; [ 6, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xF3          ] ; set       ; [ 6, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xF4          ] ; set       ; [ 6, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xF5          ] ; set       ; [ 6, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xF6          ] ; set       ; [ 6, (HL)         ] ; mem  ; 15 ; false ]
[ [0xCB, 0xF7          ] ; set       ; [ 6, A            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xF8          ] ; set       ; [ 7, B            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xF9          ] ; set       ; [ 7, C            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xFA          ] ; set       ; [ 7, D            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xFB          ] ; set       ; [ 7, E            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xFC          ] ; set       ; [ 7, H            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xFD          ] ; set       ; [ 7, L            ] ; mem  ;  8 ; false ]
[ [0xCB, 0xFE          ] ; set       ; [ 7, (HL)         ] ; mem  ; 15 ; false ]
[ [0xCB, 0xFF          ] ; set       ; [ 7, A            ] ; mem  ;  8 ; false ]
[ [0xCC, n, n          ] ; callcc    ; [ Zcc, $nn        ] ; mem  ;  0 ; false ]
[ [0xCD, n, n          ] ; call      ; [ $nn             ] ; mem  ; 17 ; false ]
[ [0xCE, n             ] ; adc       ; [ A, $n           ] ; mem  ;  7 ; false ]
[ [0xCF                ] ; rst       ; [ 0x08            ] ; mem  ; 11 ; false ]
[ [0xD0                ] ; retcc     ; [ NCcc            ] ; mem  ;  5 ; false ]
[ [0xD1                ] ; pop       ; [ DE              ] ; mem  ; 10 ; false ]
[ [0xD2, n, n          ] ; jpcc      ; [ NCcc, $nn       ] ; no   ; 10 ; false ]
[ [0xD3, n             ] ; out_n     ; [ $n, A           ] ; io   ; 11 ; false ]
[ [0xD4, n, n          ] ; callcc    ; [ NCcc, $nn       ] ; mem  ;  0 ; false ]
[ [0xD5                ] ; push      ; [ DE              ] ; mem  ; 11 ; false ]
[ [0xD6, n             ] ; sub       ; [ A, $n           ] ; mem  ;  7 ; false ]
[ [0xD7                ] ; rst       ; [ 0x10            ] ; mem  ; 11 ; false ]
[ [0xD8                ] ; retcc     ; [ Ccc             ] ; mem  ;  5 ; false ]
[ [0xD9                ] ; exx       ; [                 ] ; no   ;  4 ; false ]
[ [0xDA, n, n          ] ; jpcc      ; [ Ccc, $nn        ] ; no   ; 10 ; false ]
[ [0xDB, n             ] ; in_n      ; [ A, $n           ] ; io   ; 11 ; false ]
[ [0xDC, n, n          ] ; callcc    ; [ Ccc, $nn        ] ; mem  ;  0 ; false ]
[ [0xDD, 0x09          ] ; add16     ; [ IX, BC          ] ; no   ; 15 ; false ]
[ [0xDD, 0x19          ] ; add16     ; [ IX, DE          ] ; no   ; 15 ; false ]
[ [0xDD, 0x21, n, n    ] ; ld16      ; [ IX, $nn         ] ; mem  ; 14 ; false ]
[ [0xDD, 0x22, n, n    ] ; ld16      ; [ ($nn), IX       ] ; mem  ; 20 ; false ]
[ [0xDD, 0x23          ] ; inc16     ; [ IX              ] ; no   ; 10 ; false ]
[ [0xDD, 0x24          ] ; inc       ; [ IXH             ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x25          ] ; dec       ; [ IXH             ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x26, n       ] ; ld        ; [ IXH, $n         ] ; mem  ; 11 ; true  ]
[ [0xDD, 0x29          ] ; add16     ; [ IX, IX          ] ; no   ; 15 ; false ]
[ [0xDD, 0x2A, n, n    ] ; ld16      ; [ IX, ($nn)       ] ; mem  ; 20 ; false ]
[ [0xDD, 0x2B          ] ; dec16     ; [ IX              ] ; no   ; 10 ; false ]
[ [0xDD, 0x2C          ] ; inc       ; [ IXL             ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x2D          ] ; dec       ; [ IXL             ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x2E, n       ] ; ld        ; [ IXL, $n         ] ; mem  ; 11 ; true  ]
[ [0xDD, 0x34, d       ] ; inc       ; [ (IX+d)          ] ; mem  ; 23 ; false ]
[ [0xDD, 0x35, d       ] ; dec       ; [ (IX+d)          ] ; mem  ; 23 ; false ]
[ [0xDD, 0x36, d, n    ] ; ld        ; [ (IX+d), $n      ] ; mem  ; 19 ; false ]
[ [0xDD, 0x39          ] ; add16     ; [ IX, SP          ] ; no   ; 15 ; false ]
[ [0xDD, 0x44          ] ; ld        ; [ B, IXH          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x45          ] ; ld        ; [ B, IXL          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x46, d       ] ; ld        ; [ B, (IX+d)       ] ; mem  ; 19 ; false ]
[ [0xDD, 0x4C          ] ; ld        ; [ C, IXH          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x4D          ] ; ld        ; [ C, IXL          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x4E, d       ] ; ld        ; [ C, (IX+d)       ] ; mem  ; 19 ; false ]
[ [0xDD, 0x54          ] ; ld        ; [ D, IXH          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x55          ] ; ld        ; [ D, IXL          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x56, d       ] ; ld        ; [ D, (IX+d)       ] ; mem  ; 19 ; false ]
[ [0xDD, 0x5C          ] ; ld        ; [ E, IXH          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x5D          ] ; ld        ; [ E, IXL          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x5E, d       ] ; ld        ; [ E, (IX+d)       ] ; mem  ; 19 ; false ]
[ [0xDD, 0x60          ] ; ld        ; [ IXH, B          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x61          ] ; ld        ; [ IXH, C          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x62          ] ; ld        ; [ IXH, D          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x63          ] ; ld        ; [ IXH, E          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x64          ] ; ld        ; [ IXH, IXH        ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x65          ] ; ld        ; [ IXH, IXL        ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x66, d       ] ; ld        ; [ H, (IX+d)       ] ; mem  ; 19 ; false ]
[ [0xDD, 0x67          ] ; ld        ; [ IXH, A          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x68          ] ; ld        ; [ IXL, B          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x69          ] ; ld        ; [ IXL, C          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x6A          ] ; ld        ; [ IXL, D          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x6B          ] ; ld        ; [ IXL, E          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x6C          ] ; ld        ; [ IXL, IXH        ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x6D          ] ; ld        ; [ IXL, IXL        ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x6E, d       ] ; ld        ; [ L, (IX+d)       ] ; mem  ; 19 ; false ]
[ [0xDD, 0x6F          ] ; ld        ; [ IXL, A          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x70, d       ] ; ld        ; [ (IX+d), B       ] ; mem  ; 19 ; false ]
[ [0xDD, 0x71, d       ] ; ld        ; [ (IX+d), C       ] ; mem  ; 19 ; false ]
[ [0xDD, 0x72, d       ] ; ld        ; [ (IX+d), D       ] ; mem  ; 19 ; false ]
[ [0xDD, 0x73, d       ] ; ld        ; [ (IX+d), E       ] ; mem  ; 19 ; false ]
[ [0xDD, 0x74, d       ] ; ld        ; [ (IX+d), H       ] ; mem  ; 19 ; false ]
[ [0xDD, 0x75, d       ] ; ld        ; [ (IX+d), L       ] ; mem  ; 19 ; false ]
[ [0xDD, 0x77, d       ] ; ld        ; [ (IX+d), A       ] ; mem  ; 19 ; false ]
[ [0xDD, 0x7C          ] ; ld        ; [ A, IXH          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x7D          ] ; ld        ; [ A, IXL          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x7E, d       ] ; ld        ; [ A, (IX+d)       ] ; mem  ; 19 ; false ]
[ [0xDD, 0x84          ] ; add       ; [ A, IXH          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x85          ] ; add       ; [ A, IXL          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x86, d       ] ; add       ; [ A, (IX+d)       ] ; mem  ; 19 ; false ]
[ [0xDD, 0x8C          ] ; adc       ; [ A, IXH          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x8D          ] ; adc       ; [ A, IXL          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x8E, d       ] ; adc       ; [ A, (IX+d)       ] ; mem  ; 19 ; false ]
[ [0xDD, 0x94          ] ; sub       ; [ A, IXH          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x95          ] ; sub       ; [ A, IXL          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x96, d       ] ; sub       ; [ A, (IX+d)       ] ; mem  ; 19 ; false ]
[ [0xDD, 0x9C          ] ; sbc       ; [ A, IXH          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x9D          ] ; sbc       ; [ A, IXL          ] ; mem  ;  8 ; true  ]
[ [0xDD, 0x9E, d       ] ; sbc       ; [ A, (IX+d)       ] ; mem  ; 19 ; false ]
[ [0xDD, 0xA4          ] ; and       ; [ IXH             ] ; mem  ;  8 ; true  ]
[ [0xDD, 0xA5          ] ; and       ; [ IXL             ] ; mem  ;  8 ; true  ]
[ [0xDD, 0xA6, d       ] ; and       ; [ (IX+d)          ] ; mem  ; 19 ; false ]
[ [0xDD, 0xAC          ] ; xor       ; [ IXH             ] ; mem  ;  8 ; true  ]
[ [0xDD, 0xAD          ] ; xor       ; [ IXL             ] ; mem  ;  8 ; true  ]
[ [0xDD, 0xAE, d       ] ; xor       ; [ (IX+d)          ] ; mem  ; 19 ; false ]
[ [0xDD, 0xB4          ] ; or        ; [ IXH             ] ; mem  ;  8 ; true  ]
[ [0xDD, 0xB5          ] ; or        ; [ IXL             ] ; mem  ;  8 ; true  ]
[ [0xDD, 0xB6, d       ] ; or        ; [ (IX+d)          ] ; mem  ; 19 ; false ]
[ [0xDD, 0xBC          ] ; cp        ; [ IXH             ] ; mem  ;  8 ; true  ]
[ [0xDD, 0xBD          ] ; cp        ; [ IXL             ] ; mem  ;  8 ; true  ]
[ [0xDD, 0xBE, d       ] ; cp        ; [ (IX+d)          ] ; mem  ; 19 ; false ]
[ [0xDD, 0xCB, d, 0x00 ] ; rlc_store ; [ (IX+d), B       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x01 ] ; rlc_store ; [ (IX+d), C       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x02 ] ; rlc_store ; [ (IX+d), D       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x03 ] ; rlc_store ; [ (IX+d), E       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x04 ] ; rlc_store ; [ (IX+d), H       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x05 ] ; rlc_store ; [ (IX+d), L       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x06 ] ; rlc       ; [ (IX+d)          ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0x07 ] ; rlc_store ; [ (IX+d), A       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x08 ] ; rrc_store ; [ (IX+d), B       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x09 ] ; rrc_store ; [ (IX+d), C       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x0A ] ; rrc_store ; [ (IX+d), D       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x0B ] ; rrc_store ; [ (IX+d), E       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x0C ] ; rrc_store ; [ (IX+d), H       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x0D ] ; rrc_store ; [ (IX+d), L       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x0E ] ; rrc       ; [ (IX+d)          ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0x0F ] ; rrc_store ; [ (IX+d), A       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x10 ] ; rl_store  ; [ (IX+d), B       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x11 ] ; rl_store  ; [ (IX+d), C       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x12 ] ; rl_store  ; [ (IX+d), D       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x13 ] ; rl_store  ; [ (IX+d), E       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x14 ] ; rl_store  ; [ (IX+d), H       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x15 ] ; rl_store  ; [ (IX+d), L       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x16 ] ; rl        ; [ (IX+d)          ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0x17 ] ; rl_store  ; [ (IX+d), A       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x18 ] ; rr_store  ; [ (IX+d), B       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x19 ] ; rr_store  ; [ (IX+d), C       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x1A ] ; rr_store  ; [ (IX+d), D       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x1B ] ; rr_store  ; [ (IX+d), E       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x1C ] ; rr_store  ; [ (IX+d), H       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x1D ] ; rr_store  ; [ (IX+d), L       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x1E ] ; rr        ; [ (IX+d)          ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0x1F ] ; rr_store  ; [ (IX+d), A       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x20 ] ; sla_store ; [ (IX+d), B       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x21 ] ; sla_store ; [ (IX+d), C       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x22 ] ; sla_store ; [ (IX+d), D       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x23 ] ; sla_store ; [ (IX+d), E       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x24 ] ; sla_store ; [ (IX+d), H       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x25 ] ; sla_store ; [ (IX+d), L       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x26 ] ; sla       ; [ (IX+d)          ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0x27 ] ; sla_store ; [ (IX+d), A       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x28 ] ; sra_store ; [ (IX+d), B       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x29 ] ; sra_store ; [ (IX+d), C       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x2A ] ; sra_store ; [ (IX+d), D       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x2B ] ; sra_store ; [ (IX+d), E       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x2C ] ; sra_store ; [ (IX+d), H       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x2D ] ; sra_store ; [ (IX+d), L       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x2E ] ; sra       ; [ (IX+d)          ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0x2F ] ; sra_store ; [ (IX+d), A       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x30 ] ; sll_store ; [ (IX+d), B       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x31 ] ; sll_store ; [ (IX+d), C       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x32 ] ; sll_store ; [ (IX+d), D       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x33 ] ; sll_store ; [ (IX+d), E       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x34 ] ; sll_store ; [ (IX+d), H       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x35 ] ; sll_store ; [ (IX+d), L       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x36 ] ; sll       ; [ (IX+d)          ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x37 ] ; sll_store ; [ (IX+d), A       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x38 ] ; srl_store ; [ (IX+d), B       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x39 ] ; srl_store ; [ (IX+d), C       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x3A ] ; srl_store ; [ (IX+d), D       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x3B ] ; srl_store ; [ (IX+d), E       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x3C ] ; srl_store ; [ (IX+d), H       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x3D ] ; srl_store ; [ (IX+d), L       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x3E ] ; srl       ; [ (IX+d)          ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0x3F ] ; srl_store ; [ (IX+d), A       ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x40 ] ; bit       ; [ 0, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x41 ] ; bit       ; [ 0, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x42 ] ; bit       ; [ 0, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x43 ] ; bit       ; [ 0, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x44 ] ; bit       ; [ 0, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x45 ] ; bit       ; [ 0, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x46 ] ; bit       ; [ 0, (IX+d)       ] ; mem  ; 20 ; false ]
[ [0xDD, 0xCB, d, 0x47 ] ; bit       ; [ 0, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x48 ] ; bit       ; [ 1, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x49 ] ; bit       ; [ 1, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x4A ] ; bit       ; [ 1, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x4B ] ; bit       ; [ 1, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x4C ] ; bit       ; [ 1, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x4D ] ; bit       ; [ 1, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x4E ] ; bit       ; [ 1, (IX+d)       ] ; mem  ; 20 ; false ]
[ [0xDD, 0xCB, d, 0x4F ] ; bit       ; [ 1, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x50 ] ; bit       ; [ 2, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x51 ] ; bit       ; [ 2, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x52 ] ; bit       ; [ 2, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x53 ] ; bit       ; [ 2, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x54 ] ; bit       ; [ 2, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x55 ] ; bit       ; [ 2, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x56 ] ; bit       ; [ 2, (IX+d)       ] ; mem  ; 20 ; false ]
[ [0xDD, 0xCB, d, 0x57 ] ; bit       ; [ 2, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x58 ] ; bit       ; [ 3, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x59 ] ; bit       ; [ 3, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x5A ] ; bit       ; [ 3, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x5B ] ; bit       ; [ 3, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x5C ] ; bit       ; [ 3, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x5D ] ; bit       ; [ 3, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x5E ] ; bit       ; [ 3, (IX+d)       ] ; mem  ; 20 ; false ]
[ [0xDD, 0xCB, d, 0x5F ] ; bit       ; [ 3, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x60 ] ; bit       ; [ 4, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x61 ] ; bit       ; [ 4, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x62 ] ; bit       ; [ 4, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x63 ] ; bit       ; [ 4, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x64 ] ; bit       ; [ 4, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x65 ] ; bit       ; [ 4, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x66 ] ; bit       ; [ 4, (IX+d)       ] ; mem  ; 20 ; false ]
[ [0xDD, 0xCB, d, 0x67 ] ; bit       ; [ 4, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x68 ] ; bit       ; [ 5, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x69 ] ; bit       ; [ 5, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x6A ] ; bit       ; [ 5, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x6B ] ; bit       ; [ 5, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x6C ] ; bit       ; [ 5, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x6D ] ; bit       ; [ 5, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x6E ] ; bit       ; [ 5, (IX+d)       ] ; mem  ; 20 ; false ]
[ [0xDD, 0xCB, d, 0x6F ] ; bit       ; [ 5, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x70 ] ; bit       ; [ 6, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x71 ] ; bit       ; [ 6, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x72 ] ; bit       ; [ 6, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x73 ] ; bit       ; [ 6, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x74 ] ; bit       ; [ 6, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x75 ] ; bit       ; [ 6, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x76 ] ; bit       ; [ 6, (IX+d)       ] ; mem  ; 20 ; false ]
[ [0xDD, 0xCB, d, 0x77 ] ; bit       ; [ 6, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x78 ] ; bit       ; [ 7, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x79 ] ; bit       ; [ 7, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x7A ] ; bit       ; [ 7, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x7B ] ; bit       ; [ 7, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x7C ] ; bit       ; [ 7, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x7D ] ; bit       ; [ 7, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x7E ] ; bit       ; [ 7, (IX+d)       ] ; mem  ; 20 ; false ]
[ [0xDD, 0xCB, d, 0x7F ] ; bit       ; [ 7, (IX+d)       ] ; mem  ; 20 ; true  ]
[ [0xDD, 0xCB, d, 0x80 ] ; res_store ; [ 0, (IX+d), B    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x81 ] ; res_store ; [ 0, (IX+d), C    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x82 ] ; res_store ; [ 0, (IX+d), D    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x83 ] ; res_store ; [ 0, (IX+d), E    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x84 ] ; res_store ; [ 0, (IX+d), H    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x85 ] ; res_store ; [ 0, (IX+d), L    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x86 ] ; res       ; [ 0, (IX+d)       ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0x87 ] ; res_store ; [ 0, (IX+d), A    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x88 ] ; res_store ; [ 1, (IX+d), B    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x89 ] ; res_store ; [ 1, (IX+d), C    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x8A ] ; res_store ; [ 1, (IX+d), D    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x8B ] ; res_store ; [ 1, (IX+d), E    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x8C ] ; res_store ; [ 1, (IX+d), H    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x8D ] ; res_store ; [ 1, (IX+d), L    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x8E ] ; res       ; [ 1, (IX+d)       ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0x8F ] ; res_store ; [ 1, (IX+d), A    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x90 ] ; res_store ; [ 2, (IX+d), B    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x91 ] ; res_store ; [ 2, (IX+d), C    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x92 ] ; res_store ; [ 2, (IX+d), D    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x93 ] ; res_store ; [ 2, (IX+d), E    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x94 ] ; res_store ; [ 2, (IX+d), H    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x95 ] ; res_store ; [ 2, (IX+d), L    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x96 ] ; res       ; [ 2, (IX+d)       ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0x97 ] ; res_store ; [ 2, (IX+d), A    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x98 ] ; res_store ; [ 3, (IX+d), B    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x99 ] ; res_store ; [ 3, (IX+d), C    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x9A ] ; res_store ; [ 3, (IX+d), D    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x9B ] ; res_store ; [ 3, (IX+d), E    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x9C ] ; res_store ; [ 3, (IX+d), H    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x9D ] ; res_store ; [ 3, (IX+d), L    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0x9E ] ; res       ; [ 3, (IX+d)       ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0x9F ] ; res_store ; [ 3, (IX+d), A    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xA0 ] ; res_store ; [ 4, (IX+d), B    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xA1 ] ; res_store ; [ 4, (IX+d), C    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xA2 ] ; res_store ; [ 4, (IX+d), D    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xA3 ] ; res_store ; [ 4, (IX+d), E    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xA4 ] ; res_store ; [ 4, (IX+d), H    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xA5 ] ; res_store ; [ 4, (IX+d), L    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xA6 ] ; res       ; [ 4, (IX+d)       ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0xA7 ] ; res_store ; [ 4, (IX+d), A    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xA8 ] ; res_store ; [ 5, (IX+d), B    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xA9 ] ; res_store ; [ 5, (IX+d), C    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xAA ] ; res_store ; [ 5, (IX+d), D    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xAB ] ; res_store ; [ 5, (IX+d), E    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xAC ] ; res_store ; [ 5, (IX+d), H    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xAD ] ; res_store ; [ 5, (IX+d), L    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xAE ] ; res       ; [ 5, (IX+d)       ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0xAF ] ; res_store ; [ 5, (IX+d), A    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xB0 ] ; res_store ; [ 6, (IX+d), B    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xB1 ] ; res_store ; [ 6, (IX+d), C    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xB2 ] ; res_store ; [ 6, (IX+d), D    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xB3 ] ; res_store ; [ 6, (IX+d), E    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xB4 ] ; res_store ; [ 6, (IX+d), H    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xB5 ] ; res_store ; [ 6, (IX+d), L    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xB6 ] ; res       ; [ 6, (IX+d)       ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0xB7 ] ; res_store ; [ 6, (IX+d), A    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xB8 ] ; res_store ; [ 7, (IX+d), B    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xB9 ] ; res_store ; [ 7, (IX+d), C    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xBA ] ; res_store ; [ 7, (IX+d), D    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xBB ] ; res_store ; [ 7, (IX+d), E    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xBC ] ; res_store ; [ 7, (IX+d), H    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xBD ] ; res_store ; [ 7, (IX+d), L    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xBE ] ; res       ; [ 7, (IX+d)       ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0xBF ] ; res_store ; [ 7, (IX+d), A    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xC0 ] ; set_store ; [ 0, (IX+d), B    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xC1 ] ; set_store ; [ 0, (IX+d), C    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xC2 ] ; set_store ; [ 0, (IX+d), D    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xC3 ] ; set_store ; [ 0, (IX+d), E    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xC4 ] ; set_store ; [ 0, (IX+d), H    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xC5 ] ; set_store ; [ 0, (IX+d), L    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xC6 ] ; set       ; [ 0, (IX+d)       ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0xC7 ] ; set_store ; [ 0, (IX+d), A    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xC8 ] ; set_store ; [ 1, (IX+d), B    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xC9 ] ; set_store ; [ 1, (IX+d), C    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xCA ] ; set_store ; [ 1, (IX+d), D    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xCB ] ; set_store ; [ 1, (IX+d), E    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xCC ] ; set_store ; [ 1, (IX+d), H    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xCD ] ; set_store ; [ 1, (IX+d), L    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xCE ] ; set       ; [ 1, (IX+d)       ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0xCF ] ; set_store ; [ 1, (IX+d), A    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xD0 ] ; set_store ; [ 2, (IX+d), B    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xD1 ] ; set_store ; [ 2, (IX+d), C    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xD2 ] ; set_store ; [ 2, (IX+d), D    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xD3 ] ; set_store ; [ 2, (IX+d), E    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xD4 ] ; set_store ; [ 2, (IX+d), H    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xD5 ] ; set_store ; [ 2, (IX+d), L    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xD6 ] ; set       ; [ 2, (IX+d)       ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0xD7 ] ; set_store ; [ 2, (IX+d), A    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xD8 ] ; set_store ; [ 3, (IX+d), B    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xD9 ] ; set_store ; [ 3, (IX+d), C    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xDA ] ; set_store ; [ 3, (IX+d), D    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xDB ] ; set_store ; [ 3, (IX+d), E    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xDC ] ; set_store ; [ 3, (IX+d), H    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xDD ] ; set_store ; [ 3, (IX+d), L    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xDE ] ; set       ; [ 3, (IX+d)       ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0xDF ] ; set_store ; [ 3, (IX+d), A    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xE0 ] ; set_store ; [ 4, (IX+d), B    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xE1 ] ; set_store ; [ 4, (IX+d), C    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xE2 ] ; set_store ; [ 4, (IX+d), D    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xE3 ] ; set_store ; [ 4, (IX+d), E    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xE4 ] ; set_store ; [ 4, (IX+d), H    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xE5 ] ; set_store ; [ 4, (IX+d), L    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xE6 ] ; set       ; [ 4, (IX+d)       ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0xE7 ] ; set_store ; [ 4, (IX+d), A    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xE8 ] ; set_store ; [ 5, (IX+d), B    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xE9 ] ; set_store ; [ 5, (IX+d), C    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xEA ] ; set_store ; [ 5, (IX+d), D    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xEB ] ; set_store ; [ 5, (IX+d), E    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xEC ] ; set_store ; [ 5, (IX+d), H    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xED ] ; set_store ; [ 5, (IX+d), L    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xEE ] ; set       ; [ 5, (IX+d)       ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0xEF ] ; set_store ; [ 5, (IX+d), A    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xF0 ] ; set_store ; [ 6, (IX+d), B    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xF1 ] ; set_store ; [ 6, (IX+d), C    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xF2 ] ; set_store ; [ 6, (IX+d), D    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xF3 ] ; set_store ; [ 6, (IX+d), E    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xF4 ] ; set_store ; [ 6, (IX+d), H    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xF5 ] ; set_store ; [ 6, (IX+d), L    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xF6 ] ; set       ; [ 6, (IX+d)       ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0xF7 ] ; set_store ; [ 6, (IX+d), A    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xF8 ] ; set_store ; [ 7, (IX+d), B    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xF9 ] ; set_store ; [ 7, (IX+d), C    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xFA ] ; set_store ; [ 7, (IX+d), D    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xFB ] ; set_store ; [ 7, (IX+d), E    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xFC ] ; set_store ; [ 7, (IX+d), H    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xFD ] ; set_store ; [ 7, (IX+d), L    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xCB, d, 0xFE ] ; set       ; [ 7, (IX+d)       ] ; mem  ; 23 ; false ]
[ [0xDD, 0xCB, d, 0xFF ] ; set_store ; [ 7, (IX+d), A    ] ; mem  ; 23 ; true  ]
[ [0xDD, 0xE1          ] ; pop       ; [ IX              ] ; mem  ; 14 ; false ]
[ [0xDD, 0xE3          ] ; ex        ; [ (SP), IX        ] ; mem  ; 23 ; false ]
[ [0xDD, 0xE5          ] ; push      ; [ IX              ] ; mem  ; 15 ; false ]
[ [0xDD, 0xE9          ] ; jp        ; [ IX              ] ; no   ;  8 ; false ]
[ [0xDD, 0xF9          ] ; ld16      ; [ SP, IX          ] ; mem  ; 10 ; false ]
[ [0xDE, n             ] ; sbc       ; [ A, $n           ] ; mem  ;  7 ; false ]
[ [0xDF                ] ; rst       ; [ 0x18            ] ; mem  ; 11 ; false ]
[ [0xE0                ] ; retcc     ; [ POcc            ] ; mem  ;  5 ; false ]
[ [0xE1                ] ; pop       ; [ HL              ] ; mem  ; 10 ; false ]
[ [0xE2, n, n          ] ; jpcc      ; [ POcc, $nn       ] ; no   ; 10 ; false ]
[ [0xE3                ] ; ex        ; [ (SP), HL        ] ; mem  ; 19 ; false ]
[ [0xE4, n, n          ] ; callcc    ; [ POcc, $nn       ] ; mem  ;  0 ; false ]
[ [0xE5                ] ; push      ; [ HL              ] ; mem  ; 11 ; false ]
[ [0xE6, n             ] ; and       ; [ $n              ] ; mem  ;  7 ; false ]
[ [0xE7                ] ; rst       ; [ 0x20            ] ; mem  ; 11 ; false ]
[ [0xE8                ] ; retcc     ; [ PEcc            ] ; mem  ;  5 ; false ]
[ [0xE9                ] ; jp        ; [ HL              ] ; no   ;  4 ; false ]
[ [0xEA, n, n          ] ; jpcc      ; [ PEcc, $nn       ] ; no   ; 10 ; false ]
[ [0xEB                ] ; ex        ; [ DE, HL          ] ; mem  ;  4 ; false ]
[ [0xEC, n, n          ] ; callcc    ; [ PEcc, $nn       ] ; mem  ;  0 ; false ]
[ [0xED, 0x40          ] ; in_c      ; [ B, C            ] ; io   ; 12 ; false ]
[ [0xED, 0x41          ] ; out_c     ; [ C, B            ] ; io   ; 12 ; false ]
[ [0xED, 0x42          ] ; sbc16     ; [ HL, BC          ] ; no   ; 15 ; false ]
[ [0xED, 0x43, n, n    ] ; ld16      ; [ ($nn), BC       ] ; mem  ; 20 ; false ]
[ [0xED, 0x44          ] ; neg       ; [                 ] ; no   ;  8 ; false ]
[ [0xED, 0x45          ] ; retn      ; [                 ] ; mem  ; 14 ; false ]
[ [0xED, 0x46          ] ; im        ; [ 0               ] ; no   ;  8 ; false ]
[ [0xED, 0x47          ] ; ld        ; [ I, A            ] ; mem  ;  9 ; false ]
[ [0xED, 0x48          ] ; in_c      ; [ C, C            ] ; io   ; 12 ; false ]
[ [0xED, 0x49          ] ; out_c     ; [ C, C            ] ; io   ; 12 ; false ]
[ [0xED, 0x4A          ] ; adc16     ; [ HL, BC          ] ; no   ; 15 ; false ]
[ [0xED, 0x4B, n, n    ] ; ld16      ; [ BC, ($nn)       ] ; mem  ; 20 ; false ]
[ [0xED, 0x4C          ] ; neg       ; [                 ] ; no   ;  8 ; true  ]
[ [0xED, 0x4D          ] ; reti      ; [                 ] ; mem  ; 14 ; false ]
[ [0xED, 0x4E          ] ; im        ; [ 0               ] ; no   ;  8 ; true  ]
[ [0xED, 0x4F          ] ; ld        ; [ R, A            ] ; mem  ;  9 ; false ]
[ [0xED, 0x50          ] ; in_c      ; [ D, C            ] ; io   ; 12 ; false ]
[ [0xED, 0x51          ] ; out_c     ; [ C, D            ] ; io   ; 12 ; false ]
[ [0xED, 0x52          ] ; sbc16     ; [ HL, DE          ] ; no   ; 15 ; false ]
[ [0xED, 0x53, n, n    ] ; ld16      ; [ ($nn), DE       ] ; mem  ; 20 ; false ]
[ [0xED, 0x54          ] ; neg       ; [                 ] ; no   ;  8 ; true  ]
[ [0xED, 0x55          ] ; retn      ; [                 ] ; mem  ; 14 ; true  ]
[ [0xED, 0x56          ] ; im        ; [ 1               ] ; no   ;  8 ; false ]
[ [0xED, 0x57          ] ; ld_ir     ; [ A, I            ] ; no   ;  9 ; false ]
[ [0xED, 0x58          ] ; in_c      ; [ E, C            ] ; io   ; 12 ; false ]
[ [0xED, 0x59          ] ; out_c     ; [ C, E            ] ; io   ; 12 ; false ]
[ [0xED, 0x5A          ] ; adc16     ; [ HL, DE          ] ; no   ; 15 ; false ]
[ [0xED, 0x5B, n, n    ] ; ld16      ; [ DE, ($nn)       ] ; mem  ; 20 ; false ]
[ [0xED, 0x5C          ] ; neg       ; [                 ] ; no   ;  8 ; true  ]
[ [0xED, 0x5D          ] ; retn      ; [                 ] ; mem  ; 14 ; true  ]
[ [0xED, 0x5E          ] ; im        ; [ 2               ] ; no   ;  8 ; false ]
[ [0xED, 0x5F          ] ; ld_ir     ; [ A, R            ] ; no   ;  9 ; false ]
[ [0xED, 0x60          ] ; in_c      ; [ H, C            ] ; io   ; 12 ; false ]
[ [0xED, 0x61          ] ; out_c     ; [ C, H            ] ; io   ; 12 ; false ]
[ [0xED, 0x62          ] ; sbc16     ; [ HL, HL          ] ; no   ; 15 ; false ]
[ [0xED, 0x63, n, n    ] ; ld16      ; [ ($nn), HL       ] ; mem  ; 20 ; false ]
[ [0xED, 0x64          ] ; neg       ; [                 ] ; no   ;  8 ; true  ]
[ [0xED, 0x65          ] ; retn      ; [                 ] ; mem  ; 14 ; true  ]
[ [0xED, 0x66          ] ; im        ; [ 0               ] ; no   ;  8 ; true  ]
[ [0xED, 0x67          ] ; rrd       ; [                 ] ; mem  ; 18 ; false ]
[ [0xED, 0x68          ] ; in_c      ; [ L, C            ] ; io   ; 12 ; false ]
[ [0xED, 0x69          ] ; out_c     ; [ C, L            ] ; io   ; 12 ; false ]
[ [0xED, 0x6A          ] ; adc16     ; [ HL, HL          ] ; no   ; 15 ; false ]
[ [0xED, 0x6B, n, n    ] ; ld16      ; [ HL, ($nn)       ] ; mem  ; 20 ; false ]
[ [0xED, 0x6C          ] ; neg       ; [                 ] ; no   ;  8 ; true  ]
[ [0xED, 0x6D          ] ; retn      ; [                 ] ; mem  ; 14 ; true  ]
[ [0xED, 0x6E          ] ; im        ; [ 0               ] ; no   ;  8 ; true  ]
[ [0xED, 0x6F          ] ; rld       ; [                 ] ; mem  ; 18 ; false ]
[ [0xED, 0x70          ] ; in_f      ; [ C               ] ; io   ; 12 ; true  ]
[ [0xED, 0x71          ] ; out_c     ; [ C, 0            ] ; io   ; 12 ; true  ]
[ [0xED, 0x72          ] ; sbc16     ; [ HL, SP          ] ; no   ; 15 ; false ]
[ [0xED, 0x73, n, n    ] ; ld16      ; [ ($nn), SP       ] ; mem  ; 20 ; false ]
[ [0xED, 0x74          ] ; neg       ; [                 ] ; no   ;  8 ; true  ]
[ [0xED, 0x75          ] ; retn      ; [                 ] ; mem  ; 14 ; true  ]
[ [0xED, 0x76          ] ; im        ; [ 1               ] ; no   ;  8 ; true  ]
[ [0xED, 0x78          ] ; in_c      ; [ A, C            ] ; io   ; 12 ; false ]
[ [0xED, 0x79          ] ; out_c     ; [ C, A            ] ; io   ; 12 ; false ]
[ [0xED, 0x7A          ] ; adc16     ; [ HL, SP          ] ; no   ; 15 ; false ]
[ [0xED, 0x7B, n, n    ] ; ld16      ; [ SP, ($nn)       ] ; mem  ; 20 ; false ]
[ [0xED, 0x7C          ] ; neg       ; [                 ] ; no   ;  8 ; true  ]
[ [0xED, 0x7D          ] ; retn      ; [                 ] ; mem  ; 14 ; true  ]
[ [0xED, 0x7E          ] ; im        ; [ 2               ] ; no   ;  8 ; true  ]
[ [0xED, 0xA0          ] ; ldi       ; [                 ] ; mem  ; 16 ; false ]
[ [0xED, 0xA1          ] ; cpi       ; [                 ] ; mem  ; 16 ; false ]
[ [0xED, 0xA2          ] ; ini       ; [                 ] ; both ; 16 ; false ]
[ [0xED, 0xA3          ] ; outi      ; [                 ] ; both ; 16 ; false ]
[ [0xED, 0xA8          ] ; ldd       ; [                 ] ; mem  ; 16 ; false ]
[ [0xED, 0xA9          ] ; cpd       ; [                 ] ; mem  ; 16 ; false ]
[ [0xED, 0xAA          ] ; ind       ; [                 ] ; both ; 16 ; false ]
[ [0xED, 0xAB          ] ; outd      ; [                 ] ; io   ; 16 ; false ]
[ [0xED, 0xB0          ] ; ldir      ; [                 ] ; mem  ;  0 ; false ]
[ [0xED, 0xB1          ] ; cpir      ; [                 ] ; mem  ;  0 ; false ]
[ [0xED, 0xB2          ] ; inir      ; [                 ] ; both ;  0 ; false ]
[ [0xED, 0xB3          ] ; otir      ; [                 ] ; both ;  0 ; false ]
[ [0xED, 0xB8          ] ; lddr      ; [                 ] ; mem  ;  0 ; false ]
[ [0xED, 0xB9          ] ; cpdr      ; [                 ] ; mem  ;  0 ; false ]
[ [0xED, 0xBA          ] ; indr      ; [                 ] ; both ;  0 ; false ]
[ [0xED, 0xBB          ] ; otdr      ; [                 ] ; both ;  0 ; false ]
[ [0xEE, n             ] ; xor       ; [ $n              ] ; mem  ;  7 ; false ]
[ [0xEF                ] ; rst       ; [ 0x28            ] ; mem  ; 11 ; false ]
[ [0xF0                ] ; retcc     ; [ Pcc             ] ; mem  ;  5 ; false ]
[ [0xF1                ] ; pop       ; [ AF              ] ; mem  ; 10 ; false ]
[ [0xF2, n, n          ] ; jpcc      ; [ Pcc, $nn        ] ; no   ; 10 ; false ]
[ [0xF3                ] ; di        ; [                 ] ; no   ;  4 ; false ]
[ [0xF4, n, n          ] ; callcc    ; [ Pcc, $nn        ] ; mem  ;  0 ; false ]
[ [0xF5                ] ; push      ; [ AF              ] ; mem  ; 11 ; false ]
[ [0xF6, n             ] ; or        ; [ $n              ] ; mem  ;  7 ; false ]
[ [0xF7                ] ; rst       ; [ 0x30            ] ; mem  ; 11 ; false ]
[ [0xF8                ] ; retcc     ; [ Mcc             ] ; mem  ;  5 ; false ]
[ [0xF9                ] ; ld16      ; [ SP, HL          ] ; mem  ;  6 ; false ]
[ [0xFA, n, n          ] ; jpcc      ; [ Mcc, $nn        ] ; no   ; 10 ; false ]
[ [0xFB                ] ; ei        ; [                 ] ; no   ;  4 ; false ]
[ [0xFC, n, n          ] ; callcc    ; [ Mcc, $nn        ] ; mem  ;  0 ; false ]
[ [0xFD, 0x09          ] ; add16     ; [ IY, BC          ] ; no   ; 15 ; false ]
[ [0xFD, 0x19          ] ; add16     ; [ IY, DE          ] ; no   ; 15 ; false ]
[ [0xFD, 0x21, n, n    ] ; ld16      ; [ IY, $nn         ] ; mem  ; 14 ; false ]
[ [0xFD, 0x22, n, n    ] ; ld16      ; [ ($nn), IY       ] ; mem  ; 20 ; false ]
[ [0xFD, 0x23          ] ; inc16     ; [ IY              ] ; no   ; 10 ; false ]
[ [0xFD, 0x24          ] ; inc       ; [ IYH             ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x25          ] ; dec       ; [ IYH             ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x26, n       ] ; ld        ; [ IYH, $n         ] ; mem  ; 11 ; true  ]
[ [0xFD, 0x29          ] ; add16     ; [ IY, IY          ] ; no   ; 15 ; false ]
[ [0xFD, 0x2A, n, n    ] ; ld16      ; [ IY, ($nn)       ] ; mem  ; 20 ; false ]
[ [0xFD, 0x2B          ] ; dec16     ; [ IY              ] ; no   ; 10 ; false ]
[ [0xFD, 0x2C          ] ; inc       ; [ IYL             ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x2D          ] ; dec       ; [ IYL             ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x2E, n       ] ; ld        ; [ IYL, $n         ] ; mem  ; 11 ; true  ]
[ [0xFD, 0x34, d       ] ; inc       ; [ (IY+d)          ] ; mem  ; 23 ; false ]
[ [0xFD, 0x35, d       ] ; dec       ; [ (IY+d)          ] ; mem  ; 23 ; false ]
[ [0xFD, 0x36, d, n    ] ; ld        ; [ (IY+d), $n      ] ; mem  ; 19 ; false ]
[ [0xFD, 0x39          ] ; add16     ; [ IY, SP          ] ; no   ; 15 ; false ]
[ [0xFD, 0x44          ] ; ld        ; [ B, IYH          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x45          ] ; ld        ; [ B, IYL          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x46, d       ] ; ld        ; [ B, (IY+d)       ] ; mem  ; 19 ; false ]
[ [0xFD, 0x4C          ] ; ld        ; [ C, IYH          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x4D          ] ; ld        ; [ C, IYL          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x4E, d       ] ; ld        ; [ C, (IY+d)       ] ; mem  ; 19 ; false ]
[ [0xFD, 0x54          ] ; ld        ; [ D, IYH          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x55          ] ; ld        ; [ D, IYL          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x56, d       ] ; ld        ; [ D, (IY+d)       ] ; mem  ; 19 ; false ]
[ [0xFD, 0x5C          ] ; ld        ; [ E, IYH          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x5D          ] ; ld        ; [ E, IYL          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x5E, d       ] ; ld        ; [ E, (IY+d)       ] ; mem  ; 19 ; false ]
[ [0xFD, 0x60          ] ; ld        ; [ IYH, B          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x61          ] ; ld        ; [ IYH, C          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x62          ] ; ld        ; [ IYH, D          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x63          ] ; ld        ; [ IYH, E          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x64          ] ; ld        ; [ IYH, IYH        ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x65          ] ; ld        ; [ IYH, IYL        ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x66, d       ] ; ld        ; [ H, (IY+d)       ] ; mem  ; 19 ; false ]
[ [0xFD, 0x67          ] ; ld        ; [ IYH, A          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x68          ] ; ld        ; [ IYL, B          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x69          ] ; ld        ; [ IYL, C          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x6A          ] ; ld        ; [ IYL, D          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x6B          ] ; ld        ; [ IYL, E          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x6C          ] ; ld        ; [ IYL, IYH        ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x6D          ] ; ld        ; [ IYL, IYL        ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x6E, d       ] ; ld        ; [ L, (IY+d)       ] ; mem  ; 19 ; false ]
[ [0xFD, 0x6F          ] ; ld        ; [ IYL, A          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x70, d       ] ; ld        ; [ (IY+d), B       ] ; mem  ; 19 ; false ]
[ [0xFD, 0x71, d       ] ; ld        ; [ (IY+d), C       ] ; mem  ; 19 ; false ]
[ [0xFD, 0x72, d       ] ; ld        ; [ (IY+d), D       ] ; mem  ; 19 ; false ]
[ [0xFD, 0x73, d       ] ; ld        ; [ (IY+d), E       ] ; mem  ; 19 ; false ]
[ [0xFD, 0x74, d       ] ; ld        ; [ (IY+d), H       ] ; mem  ; 19 ; false ]
[ [0xFD, 0x75, d       ] ; ld        ; [ (IY+d), L       ] ; mem  ; 19 ; false ]
[ [0xFD, 0x77, d       ] ; ld        ; [ (IY+d), A       ] ; mem  ; 19 ; false ]
[ [0xFD, 0x7C          ] ; ld        ; [ A, IYH          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x7D          ] ; ld        ; [ A, IYL          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x7E, d       ] ; ld        ; [ A, (IY+d)       ] ; mem  ; 19 ; false ]
[ [0xFD, 0x84          ] ; add       ; [ A, IYH          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x85          ] ; add       ; [ A, IYL          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x86, d       ] ; add       ; [ A, (IY+d)       ] ; mem  ; 19 ; false ]
[ [0xFD, 0x8C          ] ; adc       ; [ A, IYH          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x8D          ] ; adc       ; [ A, IYL          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x8E, d       ] ; adc       ; [ A, (IY+d)       ] ; mem  ; 19 ; false ]
[ [0xFD, 0x94          ] ; sub       ; [ A, IYH          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x95          ] ; sub       ; [ A, IYL          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x96, d       ] ; sub       ; [ A, (IY+d)       ] ; mem  ; 19 ; false ]
[ [0xFD, 0x9C          ] ; sbc       ; [ A, IYH          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x9D          ] ; sbc       ; [ A, IYL          ] ; mem  ;  8 ; true  ]
[ [0xFD, 0x9E, d       ] ; sbc       ; [ A, (IY+d)       ] ; mem  ; 19 ; false ]
[ [0xFD, 0xA4          ] ; and       ; [ IYH             ] ; mem  ;  8 ; true  ]
[ [0xFD, 0xA5          ] ; and       ; [ IYL             ] ; mem  ;  8 ; true  ]
[ [0xFD, 0xA6, d       ] ; and       ; [ (IY+d)          ] ; mem  ; 19 ; false ]
[ [0xFD, 0xAC          ] ; xor       ; [ IYH             ] ; mem  ;  8 ; true  ]
[ [0xFD, 0xAD          ] ; xor       ; [ IYL             ] ; mem  ;  8 ; true  ]
[ [0xFD, 0xAE, d       ] ; xor       ; [ (IY+d)          ] ; mem  ; 19 ; false ]
[ [0xFD, 0xB4          ] ; or        ; [ IYH             ] ; mem  ;  8 ; true  ]
[ [0xFD, 0xB5          ] ; or        ; [ IYL             ] ; mem  ;  8 ; true  ]
[ [0xFD, 0xB6, d       ] ; or        ; [ (IY+d)          ] ; mem  ; 19 ; false ]
[ [0xFD, 0xBC          ] ; cp        ; [ IYH             ] ; mem  ;  8 ; true  ]
[ [0xFD, 0xBD          ] ; cp        ; [ IYL             ] ; mem  ;  8 ; true  ]
[ [0xFD, 0xBE, d       ] ; cp        ; [ (IY+d)          ] ; mem  ; 19 ; false ]
[ [0xFD, 0xCB, d, 0x00 ] ; rlc_store ; [ (IY+d), B       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x01 ] ; rlc_store ; [ (IY+d), C       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x02 ] ; rlc_store ; [ (IY+d), D       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x03 ] ; rlc_store ; [ (IY+d), E       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x04 ] ; rlc_store ; [ (IY+d), H       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x05 ] ; rlc_store ; [ (IY+d), L       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x06 ] ; rlc       ; [ (IY+d)          ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0x07 ] ; rlc_store ; [ (IY+d), A       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x08 ] ; rrc_store ; [ (IY+d), B       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x09 ] ; rrc_store ; [ (IY+d), C       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x0A ] ; rrc_store ; [ (IY+d), D       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x0B ] ; rrc_store ; [ (IY+d), E       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x0C ] ; rrc_store ; [ (IY+d), H       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x0D ] ; rrc_store ; [ (IY+d), L       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x0E ] ; rrc       ; [ (IY+d)          ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0x0F ] ; rrc_store ; [ (IY+d), A       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x10 ] ; rl_store  ; [ (IY+d), B       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x11 ] ; rl_store  ; [ (IY+d), C       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x12 ] ; rl_store  ; [ (IY+d), D       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x13 ] ; rl_store  ; [ (IY+d), E       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x14 ] ; rl_store  ; [ (IY+d), H       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x15 ] ; rl_store  ; [ (IY+d), L       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x16 ] ; rl        ; [ (IY+d)          ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0x17 ] ; rl_store  ; [ (IY+d), A       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x18 ] ; rr_store  ; [ (IY+d), B       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x19 ] ; rr_store  ; [ (IY+d), C       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x1A ] ; rr_store  ; [ (IY+d), D       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x1B ] ; rr_store  ; [ (IY+d), E       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x1C ] ; rr_store  ; [ (IY+d), H       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x1D ] ; rr_store  ; [ (IY+d), L       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x1E ] ; rr        ; [ (IY+d)          ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0x1F ] ; rr_store  ; [ (IY+d), A       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x20 ] ; sla_store ; [ (IY+d), B       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x21 ] ; sla_store ; [ (IY+d), C       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x22 ] ; sla_store ; [ (IY+d), D       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x23 ] ; sla_store ; [ (IY+d), E       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x24 ] ; sla_store ; [ (IY+d), H       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x25 ] ; sla_store ; [ (IY+d), L       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x26 ] ; sla       ; [ (IY+d)          ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0x27 ] ; sla_store ; [ (IY+d), A       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x28 ] ; sra_store ; [ (IY+d), B       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x29 ] ; sra_store ; [ (IY+d), C       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x2A ] ; sra_store ; [ (IY+d), D       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x2B ] ; sra_store ; [ (IY+d), E       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x2C ] ; sra_store ; [ (IY+d), H       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x2D ] ; sra_store ; [ (IY+d), L       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x2E ] ; sra       ; [ (IY+d)          ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0x2F ] ; sra_store ; [ (IY+d), A       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x30 ] ; sll_store ; [ (IY+d), B       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x31 ] ; sll_store ; [ (IY+d), C       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x32 ] ; sll_store ; [ (IY+d), D       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x33 ] ; sll_store ; [ (IY+d), E       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x34 ] ; sll_store ; [ (IY+d), H       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x35 ] ; sll_store ; [ (IY+d), L       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x36 ] ; sll       ; [ (IY+d)          ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x37 ] ; sll_store ; [ (IY+d), A       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x38 ] ; srl_store ; [ (IY+d), B       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x39 ] ; srl_store ; [ (IY+d), C       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x3A ] ; srl_store ; [ (IY+d), D       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x3B ] ; srl_store ; [ (IY+d), E       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x3C ] ; srl_store ; [ (IY+d), H       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x3D ] ; srl_store ; [ (IY+d), L       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x3E ] ; srl       ; [ (IY+d)          ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0x3F ] ; srl_store ; [ (IY+d), A       ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x40 ] ; bit       ; [ 0, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x41 ] ; bit       ; [ 0, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x42 ] ; bit       ; [ 0, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x43 ] ; bit       ; [ 0, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x44 ] ; bit       ; [ 0, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x45 ] ; bit       ; [ 0, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x46 ] ; bit       ; [ 0, (IY+d)       ] ; mem  ; 20 ; false ]
[ [0xFD, 0xCB, d, 0x47 ] ; bit       ; [ 0, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x48 ] ; bit       ; [ 1, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x49 ] ; bit       ; [ 1, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x4A ] ; bit       ; [ 1, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x4B ] ; bit       ; [ 1, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x4C ] ; bit       ; [ 1, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x4D ] ; bit       ; [ 1, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x4E ] ; bit       ; [ 1, (IY+d)       ] ; mem  ; 20 ; false ]
[ [0xFD, 0xCB, d, 0x4F ] ; bit       ; [ 1, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x50 ] ; bit       ; [ 2, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x51 ] ; bit       ; [ 2, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x52 ] ; bit       ; [ 2, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x53 ] ; bit       ; [ 2, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x54 ] ; bit       ; [ 2, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x55 ] ; bit       ; [ 2, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x56 ] ; bit       ; [ 2, (IY+d)       ] ; mem  ; 20 ; false ]
[ [0xFD, 0xCB, d, 0x57 ] ; bit       ; [ 2, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x58 ] ; bit       ; [ 3, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x59 ] ; bit       ; [ 3, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x5A ] ; bit       ; [ 3, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x5B ] ; bit       ; [ 3, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x5C ] ; bit       ; [ 3, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x5D ] ; bit       ; [ 3, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x5E ] ; bit       ; [ 3, (IY+d)       ] ; mem  ; 20 ; false ]
[ [0xFD, 0xCB, d, 0x5F ] ; bit       ; [ 3, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x60 ] ; bit       ; [ 4, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x61 ] ; bit       ; [ 4, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x62 ] ; bit       ; [ 4, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x63 ] ; bit       ; [ 4, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x64 ] ; bit       ; [ 4, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x65 ] ; bit       ; [ 4, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x66 ] ; bit       ; [ 4, (IY+d)       ] ; mem  ; 20 ; false ]
[ [0xFD, 0xCB, d, 0x67 ] ; bit       ; [ 4, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x68 ] ; bit       ; [ 5, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x69 ] ; bit       ; [ 5, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x6A ] ; bit       ; [ 5, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x6B ] ; bit       ; [ 5, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x6C ] ; bit       ; [ 5, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x6D ] ; bit       ; [ 5, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x6E ] ; bit       ; [ 5, (IY+d)       ] ; mem  ; 20 ; false ]
[ [0xFD, 0xCB, d, 0x6F ] ; bit       ; [ 5, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x70 ] ; bit       ; [ 6, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x71 ] ; bit       ; [ 6, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x72 ] ; bit       ; [ 6, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x73 ] ; bit       ; [ 6, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x74 ] ; bit       ; [ 6, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x75 ] ; bit       ; [ 6, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x76 ] ; bit       ; [ 6, (IY+d)       ] ; mem  ; 20 ; false ]
[ [0xFD, 0xCB, d, 0x77 ] ; bit       ; [ 6, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x78 ] ; bit       ; [ 7, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x79 ] ; bit       ; [ 7, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x7A ] ; bit       ; [ 7, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x7B ] ; bit       ; [ 7, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x7C ] ; bit       ; [ 7, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x7D ] ; bit       ; [ 7, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x7E ] ; bit       ; [ 7, (IY+d)       ] ; mem  ; 20 ; false ]
[ [0xFD, 0xCB, d, 0x7F ] ; bit       ; [ 7, (IY+d)       ] ; mem  ; 20 ; true  ]
[ [0xFD, 0xCB, d, 0x80 ] ; res_store ; [ 0, (IY+d), B    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x81 ] ; res_store ; [ 0, (IY+d), C    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x82 ] ; res_store ; [ 0, (IY+d), D    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x83 ] ; res_store ; [ 0, (IY+d), E    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x84 ] ; res_store ; [ 0, (IY+d), H    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x85 ] ; res_store ; [ 0, (IY+d), L    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x86 ] ; res       ; [ 0, (IY+d)       ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0x87 ] ; res_store ; [ 0, (IY+d), A    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x88 ] ; res_store ; [ 1, (IY+d), B    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x89 ] ; res_store ; [ 1, (IY+d), C    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x8A ] ; res_store ; [ 1, (IY+d), D    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x8B ] ; res_store ; [ 1, (IY+d), E    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x8C ] ; res_store ; [ 1, (IY+d), H    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x8D ] ; res_store ; [ 1, (IY+d), L    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x8E ] ; res       ; [ 1, (IY+d)       ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0x8F ] ; res_store ; [ 1, (IY+d), A    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x90 ] ; res_store ; [ 2, (IY+d), B    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x91 ] ; res_store ; [ 2, (IY+d), C    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x92 ] ; res_store ; [ 2, (IY+d), D    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x93 ] ; res_store ; [ 2, (IY+d), E    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x94 ] ; res_store ; [ 2, (IY+d), H    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x95 ] ; res_store ; [ 2, (IY+d), L    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x96 ] ; res       ; [ 2, (IY+d)       ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0x97 ] ; res_store ; [ 2, (IY+d), A    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x98 ] ; res_store ; [ 3, (IY+d), B    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x99 ] ; res_store ; [ 3, (IY+d), C    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x9A ] ; res_store ; [ 3, (IY+d), D    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x9B ] ; res_store ; [ 3, (IY+d), E    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x9C ] ; res_store ; [ 3, (IY+d), H    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x9D ] ; res_store ; [ 3, (IY+d), L    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0x9E ] ; res       ; [ 3, (IY+d)       ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0x9F ] ; res_store ; [ 3, (IY+d), A    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xA0 ] ; res_store ; [ 4, (IY+d), B    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xA1 ] ; res_store ; [ 4, (IY+d), C    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xA2 ] ; res_store ; [ 4, (IY+d), D    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xA3 ] ; res_store ; [ 4, (IY+d), E    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xA4 ] ; res_store ; [ 4, (IY+d), H    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xA5 ] ; res_store ; [ 4, (IY+d), L    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xA6 ] ; res       ; [ 4, (IY+d)       ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0xA7 ] ; res_store ; [ 4, (IY+d), A    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xA8 ] ; res_store ; [ 5, (IY+d), B    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xA9 ] ; res_store ; [ 5, (IY+d), C    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xAA ] ; res_store ; [ 5, (IY+d), D    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xAB ] ; res_store ; [ 5, (IY+d), E    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xAC ] ; res_store ; [ 5, (IY+d), H    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xAD ] ; res_store ; [ 5, (IY+d), L    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xAE ] ; res       ; [ 5, (IY+d)       ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0xAF ] ; res_store ; [ 5, (IY+d), A    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xB0 ] ; res_store ; [ 6, (IY+d), B    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xB1 ] ; res_store ; [ 6, (IY+d), C    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xB2 ] ; res_store ; [ 6, (IY+d), D    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xB3 ] ; res_store ; [ 6, (IY+d), E    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xB4 ] ; res_store ; [ 6, (IY+d), H    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xB5 ] ; res_store ; [ 6, (IY+d), L    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xB6 ] ; res       ; [ 6, (IY+d)       ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0xB7 ] ; res_store ; [ 6, (IY+d), A    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xB8 ] ; res_store ; [ 7, (IY+d), B    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xB9 ] ; res_store ; [ 7, (IY+d), C    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xBA ] ; res_store ; [ 7, (IY+d), D    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xBB ] ; res_store ; [ 7, (IY+d), E    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xBC ] ; res_store ; [ 7, (IY+d), H    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xBD ] ; res_store ; [ 7, (IY+d), L    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xBE ] ; res       ; [ 7, (IY+d)       ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0xBF ] ; res_store ; [ 7, (IY+d), A    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xC0 ] ; set_store ; [ 0, (IY+d), B    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xC1 ] ; set_store ; [ 0, (IY+d), C    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xC2 ] ; set_store ; [ 0, (IY+d), D    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xC3 ] ; set_store ; [ 0, (IY+d), E    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xC4 ] ; set_store ; [ 0, (IY+d), H    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xC5 ] ; set_store ; [ 0, (IY+d), L    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xC6 ] ; set       ; [ 0, (IY+d)       ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0xC7 ] ; set_store ; [ 0, (IY+d), A    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xC8 ] ; set_store ; [ 1, (IY+d), B    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xC9 ] ; set_store ; [ 1, (IY+d), C    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xCA ] ; set_store ; [ 1, (IY+d), D    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xCB ] ; set_store ; [ 1, (IY+d), E    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xCC ] ; set_store ; [ 1, (IY+d), H    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xCD ] ; set_store ; [ 1, (IY+d), L    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xCE ] ; set       ; [ 1, (IY+d)       ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0xCF ] ; set_store ; [ 1, (IY+d), A    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xD0 ] ; set_store ; [ 2, (IY+d), B    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xD1 ] ; set_store ; [ 2, (IY+d), C    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xD2 ] ; set_store ; [ 2, (IY+d), D    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xD3 ] ; set_store ; [ 2, (IY+d), E    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xD4 ] ; set_store ; [ 2, (IY+d), H    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xD5 ] ; set_store ; [ 2, (IY+d), L    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xD6 ] ; set       ; [ 2, (IY+d)       ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0xD7 ] ; set_store ; [ 2, (IY+d), A    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xD8 ] ; set_store ; [ 3, (IY+d), B    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xD9 ] ; set_store ; [ 3, (IY+d), C    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xDA ] ; set_store ; [ 3, (IY+d), D    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xDB ] ; set_store ; [ 3, (IY+d), E    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xDC ] ; set_store ; [ 3, (IY+d), H    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xDD ] ; set_store ; [ 3, (IY+d), L    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xDE ] ; set       ; [ 3, (IY+d)       ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0xDF ] ; set_store ; [ 3, (IY+d), A    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xE0 ] ; set_store ; [ 4, (IY+d), B    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xE1 ] ; set_store ; [ 4, (IY+d), C    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xE2 ] ; set_store ; [ 4, (IY+d), D    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xE3 ] ; set_store ; [ 4, (IY+d), E    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xE4 ] ; set_store ; [ 4, (IY+d), H    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xE5 ] ; set_store ; [ 4, (IY+d), L    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xE6 ] ; set       ; [ 4, (IY+d)       ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0xE7 ] ; set_store ; [ 4, (IY+d), A    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xE8 ] ; set_store ; [ 5, (IY+d), B    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xE9 ] ; set_store ; [ 5, (IY+d), C    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xEA ] ; set_store ; [ 5, (IY+d), D    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xEB ] ; set_store ; [ 5, (IY+d), E    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xEC ] ; set_store ; [ 5, (IY+d), H    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xED ] ; set_store ; [ 5, (IY+d), L    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xEE ] ; set       ; [ 5, (IY+d)       ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0xEF ] ; set_store ; [ 5, (IY+d), A    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xF0 ] ; set_store ; [ 6, (IY+d), B    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xF1 ] ; set_store ; [ 6, (IY+d), C    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xF2 ] ; set_store ; [ 6, (IY+d), D    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xF3 ] ; set_store ; [ 6, (IY+d), E    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xF4 ] ; set_store ; [ 6, (IY+d), H    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xF5 ] ; set_store ; [ 6, (IY+d), L    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xF6 ] ; set       ; [ 6, (IY+d)       ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0xF7 ] ; set_store ; [ 6, (IY+d), A    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xF8 ] ; set_store ; [ 7, (IY+d), B    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xF9 ] ; set_store ; [ 7, (IY+d), C    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xFA ] ; set_store ; [ 7, (IY+d), D    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xFB ] ; set_store ; [ 7, (IY+d), E    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xFC ] ; set_store ; [ 7, (IY+d), H    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xFD ] ; set_store ; [ 7, (IY+d), L    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xCB, d, 0xFE ] ; set       ; [ 7, (IY+d)       ] ; mem  ; 23 ; false ]
[ [0xFD, 0xCB, d, 0xFF ] ; set_store ; [ 7, (IY+d), A    ] ; mem  ; 23 ; true  ]
[ [0xFD, 0xE1          ] ; pop       ; [ IY              ] ; mem  ; 14 ; false ]
[ [0xFD, 0xE3          ] ; ex        ; [ (SP), IY        ] ; mem  ; 23 ; false ]
[ [0xFD, 0xE5          ] ; push      ; [ IY              ] ; mem  ; 15 ; false ]
[ [0xFD, 0xE9          ] ; jp        ; [ IY              ] ; no   ;  8 ; false ]
[ [0xFD, 0xF9          ] ; ld16      ; [ SP, IY          ] ; mem  ; 10 ; false ]
[ [0xFE, n             ] ; cp        ; [ $n              ] ; mem  ;  7 ; false ]
[ [0xFF                ] ; rst       ; [ 0x38            ] ; mem  ; 11 ; false ]
        };
    };
}
